From 8c1c344b298278ada2e4b70ac01218a6227e1616 Mon Sep 17 00:00:00 2001
From: Thomas Munro <thomas.munro@gmail.com>
Date: Sun, 10 Jul 2022 11:31:58 +1200
Subject: [PATCH 5/6] Remove dead getpwuid_r replacement code.

getpwuid_r is from POSIX-1:1996 and is present in all our supported Unix
systems.
---
 configure                  |  2 +-
 configure.ac               |  2 +-
 src/include/pg_config.h.in |  3 --
 src/port/thread.c          | 58 +++-----------------------------------
 src/tools/msvc/Solution.pm |  1 -
 5 files changed, 6 insertions(+), 60 deletions(-)

diff --git a/configure b/configure
index 79d644d751..5d9150fad2 100755
--- a/configure
+++ b/configure
@@ -11599,7 +11599,7 @@ fi
 
 
 
-for ac_func in strerror_r getpwuid_r gethostbyname_r
+for ac_func in strerror_r gethostbyname_r
 do :
   as_ac_var=`$as_echo "ac_cv_func_$ac_func" | $as_tr_sh`
 ac_fn_c_check_func "$LINENO" "$ac_func" "$as_ac_var"
diff --git a/configure.ac b/configure.ac
index 59d108121d..6b7ac306a2 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1201,7 +1201,7 @@ LIBS="$LIBS $PTHREAD_LIBS"
 AC_CHECK_HEADER(pthread.h, [], [AC_MSG_ERROR([
 pthread.h not found;  use --disable-thread-safety to disable thread safety])])
 
-AC_CHECK_FUNCS([strerror_r getpwuid_r gethostbyname_r])
+AC_CHECK_FUNCS([strerror_r gethostbyname_r])
 
 # Do test here with the proper thread flags
 PGAC_FUNC_STRERROR_R_INT
diff --git a/src/include/pg_config.h.in b/src/include/pg_config.h.in
index 5b2a9db56d..716baf2e91 100644
--- a/src/include/pg_config.h.in
+++ b/src/include/pg_config.h.in
@@ -243,9 +243,6 @@
 /* Define to 1 if you have the `getpeerucred' function. */
 #undef HAVE_GETPEERUCRED
 
-/* Define to 1 if you have the `getpwuid_r' function. */
-#undef HAVE_GETPWUID_R
-
 /* Define to 1 if you have the `getrlimit' function. */
 #undef HAVE_GETRLIMIT
 
diff --git a/src/port/thread.c b/src/port/thread.c
index 23c3fbdf86..492e5a3b72 100644
--- a/src/port/thread.c
+++ b/src/port/thread.c
@@ -18,62 +18,12 @@
 
 
 /*
- *	Threading sometimes requires specially-named versions of functions
- *	that return data in static buffers, like strerror_r() instead of
- *	strerror().  Other operating systems use pthread_setspecific()
- *	and pthread_getspecific() internally to allow standard library
- *	functions to return static data to threaded applications. And some
- *	operating systems have neither.
- *
- *	Additional confusion exists because many operating systems that
- *	use pthread_setspecific/pthread_getspecific() also have *_r versions
- *	of standard library functions for compatibility with operating systems
- *	that require them.  However, internally, these *_r functions merely
- *	call the thread-safe standard library functions.
- *
- *	For example, BSD/OS 4.3 uses Bind 8.2.3 for getpwuid().  Internally,
- *	getpwuid() calls pthread_setspecific/pthread_getspecific() to return
- *	static data to the caller in a thread-safe manner.  However, BSD/OS
- *	also has getpwuid_r(), which merely calls getpwuid() and shifts
- *	around the arguments to match the getpwuid_r() function declaration.
- *	Therefore, while BSD/OS has getpwuid_r(), it isn't required.  It also
- *	doesn't have strerror_r(), so we can't fall back to only using *_r
- *	functions for threaded programs.
- *
- *	The current setup is to try threading in this order:
- *
- *		use *_r function names if they exit
- *			(*_THREADSAFE=yes)
- *		use non-*_r functions if they are thread-safe
+ *  Historically, the code in this module had to deal with operating systems
+ *  that lacked getpwuid_r().
  */
 
 #ifndef WIN32
 
-/*
- * Wrapper around getpwuid() or getpwuid_r() to mimic POSIX getpwuid_r()
- * behaviour, if that function is not available or required.
- *
- * Per POSIX, the possible cases are:
- * success: returns zero, *result is non-NULL
- * uid not found: returns zero, *result is NULL
- * error during lookup: returns an errno code, *result is NULL
- * (caller should *not* assume that the errno variable is set)
- */
-static int
-pqGetpwuid(uid_t uid, struct passwd *resultbuf, char *buffer,
-		   size_t buflen, struct passwd **result)
-{
-#if defined(FRONTEND) && defined(ENABLE_THREAD_SAFETY) && defined(HAVE_GETPWUID_R)
-	return getpwuid_r(uid, resultbuf, buffer, buflen, result);
-#else
-	/* no getpwuid_r() available, just use getpwuid() */
-	errno = 0;
-	*result = getpwuid(uid);
-	/* paranoia: ensure we return zero on success */
-	return (*result == NULL) ? errno : 0;
-#endif
-}
-
 /*
  * pg_get_user_name - get the name of the user with the given ID
  *
@@ -89,7 +39,7 @@ pg_get_user_name(uid_t user_id, char *buffer, size_t buflen)
 	struct passwd *pw = NULL;
 	int			pwerr;
 
-	pwerr = pqGetpwuid(user_id, &pwdstr, pwdbuf, sizeof(pwdbuf), &pw);
+	pwerr = getpwuid_r(user_id, &pwdstr, pwdbuf, sizeof(pwdbuf), &pw);
 	if (pw != NULL)
 	{
 		strlcpy(buffer, pw->pw_name, buflen);
@@ -125,7 +75,7 @@ pg_get_user_home_dir(uid_t user_id, char *buffer, size_t buflen)
 	struct passwd *pw = NULL;
 	int			pwerr;
 
-	pwerr = pqGetpwuid(user_id, &pwdstr, pwdbuf, sizeof(pwdbuf), &pw);
+	pwerr = getpwuid_r(user_id, &pwdstr, pwdbuf, sizeof(pwdbuf), &pw);
 	if (pw != NULL)
 	{
 		strlcpy(buffer, pw->pw_dir, buflen);
diff --git a/src/tools/msvc/Solution.pm b/src/tools/msvc/Solution.pm
index 9ad22333ee..1e83583e76 100644
--- a/src/tools/msvc/Solution.pm
+++ b/src/tools/msvc/Solution.pm
@@ -275,7 +275,6 @@ sub GenerateFiles
 		HAVE_GETOPT_LONG                            => undef,
 		HAVE_GETPEEREID                             => undef,
 		HAVE_GETPEERUCRED                           => undef,
-		HAVE_GETPWUID_R                             => undef,
 		HAVE_GETRLIMIT                              => undef,
 		HAVE_GETRUSAGE                              => undef,
 		HAVE_GETTIMEOFDAY                           => undef,
-- 
2.36.1

